import { createSlice, PayloadAction } from '@reduxjs/toolkit';
import type { RootState } from './store';

// Define the initial state using that type
export const initialState: {
  currentDatabase: string;
  databases: string[];
} = {
  currentDatabase: '',
  databases: [],
};

export const sessionSlice = createSlice({
  name: 'session',
  // `createSlice` will infer the state type from the `initialState` argument
  initialState,
  reducers: {
    updateCurrentDatabase(state, action: PayloadAction<string>) {
      state.currentDatabase = action.payload;
    },
    updateDatabaseList(state, action: PayloadAction<string[]>) {
      state.databases = action.payload;
    }
  },
});

export const {
  updateCurrentDatabase,
  updateDatabaseList
} = sessionSlice.actions;

// Other code such as selectors can use the imported `RootState` type
export const sessionCacheState = (state: RootState) => state.sessionCache;

export default sessionSlice.reducer;
