import React from 'react';
import { Meta, StoryObj } from '@storybook/react';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import { GraphPolarisThemeProvider } from '@graphpolaris/shared/lib/data-access/theme';

import {
  colorPaletteConfigSlice,
  querybuilderSlice,
  schemaSlice,
} from '@graphpolaris/shared/lib/data-access/store';
import { ReactFlowProvider } from 'reactflow';
import { AttributeAnalyticsPopupMenu } from './attribute-analytics-popup-menu';
import { AttributeCategory, NodeType } from '../../../../schema-utils/Types';

const Component: Meta<typeof AttributeAnalyticsPopupMenu> = {
  /* 👇 The title prop is optional.
   * See https://storybook.js.org/docs/react/configure/overview#configure-story-loading
   * to learn how to generate automatic titles
   */
  title: 'Schema/Pills/Popups/Menus/AttributeAnalyticsPopupMenu',
  component: AttributeAnalyticsPopupMenu,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <GraphPolarisThemeProvider>
          <ReactFlowProvider>{story()}</ReactFlowProvider>
        </GraphPolarisThemeProvider>
      </Provider>
    ),
  ],
};

export default Component;

// A super-simple mock of a redux store
const Mockstore = configureStore({
  reducer: {
    colorPaletteConfig: colorPaletteConfigSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
    // schema: schemaSlice.reducer,
  },
});

type Story = StoryObj<typeof AttributeAnalyticsPopupMenu>;
export const Default: Story = {
  args: {
    data: {
      nodeID: '1',
      nodeType: NodeType.entity,
      attributes: [
        {
          category: AttributeCategory.categorical,
          nullAmount: 0,
          attribute: {
            name: 'Foo',
            type: 'string',
          },
        },
      ],
      isAttributeDataIn: false,
      onClickCloseButton: () => {},
      onClickPlaceInQueryBuilderButton: (name: string, type) => {},
      searchForAttributes: (id: string, searchbarValue: string) => {},
      resetAttributeFilters: (id: string) => {},
      applyAttributeFilters: (
        id: string,
        category: AttributeCategory,
        predicate: string,
        percentage: number
      ) => {},
    },
  },
};
